require 'uu/os/logger/mdc_provider'

module UU
  module OS
    module VUC

      # Encapsulates methods for manipulation with diagnostic context (providing information about use case execution environment).
      module LoggerContext
        extend self

        # Sets use case context information to diagnostic context of UU::OS::Logger. Information about use case uri,
        # application instance uri, execution id, main entity uri, access role uri, executive role uri can be
        # logged.
        #
        # @param [UU::OS::VUC::Context] context information of visual use case.
        def set(context)
          return unless context.kind_of?UU::OS::VUC::Context
          put('uu-appURI', context.application_instance_uri)
          put('uu-ucURI', context.use_case_uri)
          execID = context.execution_id.nil? || context.execution_id.strip.empty? ? SecureRandom.uuid : context.execution_id
          put('uu-execID', execID)
          put('uu-entityURI', context.main_entity_uri)
          put('uu-acrURI', context.access_role_uri)
          put('uu-erURI', context.executive_role_uri)
        end

        # Clean up all UU::OS::Logger diagnostic context information.
        def clean
          mdc_copy = UU::OS::Logger::MDCProvider.get_context
          if mdc_copy.nil? || mdc_copy.empty?
            return
          end
          mdc_copy.each_key {|key| UU::OS::Logger::MDCProvider.remove key}
        end

        private

        def put(key, value)
          UU::OS::Logger::MDCProvider.put(key, value) unless value.nil?
        end
      end
    end
  end
end